pub struct ChainHeadConfig {
pub global_max_pinned_blocks: usize,
pub subscription_max_pinned_duration: Duration,
pub subscription_max_ongoing_operations: usize,
pub max_lagging_distance: usize,
pub max_follow_subscriptions_per_connection: usize,
pub subscription_buffer_cap: usize,
}Expand description
The configuration of ChainHead.
Fields
global_max_pinned_blocks: usizeThe maximum number of pinned blocks across all subscriptions.
subscription_max_pinned_duration: DurationThe maximum duration that a block is allowed to be pinned per subscription.
subscription_max_ongoing_operations: usizeThe maximum number of ongoing operations per subscription.
max_lagging_distance: usizeStop all subscriptions if the distance between the leaves and the current finalized block is larger than this value.
max_follow_subscriptions_per_connection: usizeThe maximum number of chainHead_follow subscriptions per connection.
subscription_buffer_cap: usizeThe maximum number of pending messages per subscription.